@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Base.py,v 1.8 2000/03/15 08:36:31 fredgo Exp $
+# $Id: Base.py,v 1.9 2000/03/21 11:03:36 fredgo Exp $
 
 from string import *
 import re, copy, os
@@ -234,18 +234,6 @@ class DataBase:
 	return
 
 
-    def get_native (self, key):
-	''' returns the entry in its native form '''
-
-	raise RuntimeError, "method is deferred"
-
-
-    def create_native (self, value):
-	''' returns an entry, described in input in native form '''
-
-	raise RuntimeError, "method is deferred"
-
-
     def __delitem__ (self, key):
 	''' Removes an Entry from the database, by its key '''
 
