@@ -17,7 +17,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Document.py,v 1.9 2000/03/15 08:36:32 fredgo Exp $
+# $Id: Document.py,v 1.14 2000/03/30 14:37:28 fredgo Exp $
 
 ''' This module defines a Document class '''
 
@@ -25,8 +25,16 @@ from gnome.ui import *
 from gtk import *
 from gnome import config
 
-from Pyblio.GnomeUI import Index, Entry, Utils, FileSelector, Editor, Search
+from Pyblio.GnomeUI import Index, Entry, Utils, FileSelector, Editor
+from Pyblio.GnomeUI import Search, Format
+from Pyblio.GnomeUI.Sort import SortDialog
+from Pyblio.GnomeUI.Config import ConfigDialog
+from Pyblio.GnomeUI.Fields import FieldsDialog, EntriesDialog
+
 from Pyblio import Connector, Open, Exceptions, Selection, Sort, Base, Config
+from Pyblio import version, Fields
+
+import Pyblio.Style.Utils
 
 import gettext, os, string, copy, types
 
@@ -34,7 +42,7 @@ _ = gettext.gettext
 
 class Document (Connector.Publisher):
     
-    def __init__ (self, database, version = '0.0'):
+    def __init__ (self, database):
         
         self.w = GnomeApp ('Pybliographic', 'Pybliographic')
 
@@ -43,7 +51,7 @@ class Document (Connector.Publisher):
         file_menu = [
             UIINFO_MENU_NEW_ITEM     (_("New"), None, self.new_document),
             UIINFO_MENU_OPEN_ITEM    (self.ui_open_document),
-            UIINFO_ITEM              (_("Merge..."),None, self.merge_database),
+            UIINFO_ITEM              (_("Merge with..."),None, self.merge_database),
             UIINFO_MENU_SAVE_ITEM    (self.save_document),
             UIINFO_MENU_SAVE_AS_ITEM (self.save_document_as),
             UIINFO_SEPARATOR,
@@ -76,13 +84,22 @@ class Document (Connector.Publisher):
             ]
 
         cite_menu = [
-            UIINFO_ITEM_STOCK(_("Cite"), None, self.lyx_cite,    STOCK_MENU_CONVERT),
+            UIINFO_ITEM_STOCK(_("Cite"), None, self.lyx_cite,            STOCK_MENU_CONVERT),
+            UIINFO_ITEM_STOCK(_("Format..."), None, self.format_entries, STOCK_MENU_REFRESH),
             ]
-        
+
+        settings_menu = [
+            UIINFO_ITEM      (_("Fields..."),  None, self.set_fields),
+            UIINFO_ITEM      (_("Entries..."), None, self.set_entries),
+            UIINFO_SEPARATOR,
+            UIINFO_MENU_PREFERENCES_ITEM   (self.set_preferences),
+            ]
+            
         menus = [
             UIINFO_SUBTREE (_("File"),     file_menu),
             UIINFO_SUBTREE (_("Edit"),     edit_menu),
             UIINFO_SUBTREE (_("Cite"),     cite_menu),
+            UIINFO_SUBTREE (_("Settings"), settings_menu),
             UIINFO_SUBTREE (_("Help"),     help_menu)
             ]
         
@@ -91,7 +108,7 @@ class Document (Connector.Publisher):
             UIINFO_ITEM_STOCK(_("Save"),  None, self.save_document,    STOCK_PIXMAP_SAVE),
             UIINFO_SEPARATOR,
             UIINFO_ITEM_STOCK(_("Find"),  None, self.find_entries,     STOCK_PIXMAP_SEARCH),
-            UIINFO_ITEM_STOCK(_("Cite"), None, self.lyx_cite,    STOCK_MENU_CONVERT),
+            UIINFO_ITEM_STOCK(_("Cite"), None, self.lyx_cite,          STOCK_MENU_CONVERT),
             UIINFO_SEPARATOR,
             UIINFO_ITEM_STOCK(_("Close"), None, self.close_document,   STOCK_PIXMAP_CLOSE),
             ]
@@ -111,6 +128,7 @@ class Document (Connector.Publisher):
         self.index.Subscribe ('select-entry',   self.update_display)
         self.index.Subscribe ('select-entries', self.freeze_display)
         self.index.Subscribe ('drag-received',  self.drag_received)
+        self.index.Subscribe ('drag-moved',     self.drag_moved)
         self.index.Subscribe ('click-on-field', self.sort_by_field)
 
         # The text area
@@ -142,9 +160,10 @@ class Document (Connector.Publisher):
         
         # application variables
         self.data      = database
-        self.version   = version
         self.selection = Selection.Selection ()
         self.search_dg = None
+        self.format_dg = None
+        self.sort_dg   = None
         self.lyx       = None
         self.changed   = 0
 
@@ -152,6 +171,21 @@ class Document (Connector.Publisher):
         return
 
 
+    def set_preferences (self, * arg):
+        w = ConfigDialog (self.w)
+        return
+
+
+    def set_fields (self, * arg):
+        w = FieldsDialog (self.w)
+        return
+    
+
+    def set_entries (self, * arg):
+        w = EntriesDialog (self.w)
+        return
+    
+
     def update_history (self, history):
         ''' fill the " Previous Documents " menu with the specified list of documents '''
         
@@ -183,6 +217,33 @@ class Document (Connector.Publisher):
         self.update_status ()
         return
 
+
+    def format_query (self, style, format, output):
+        try:
+            file = open (output, 'w')
+        except IOError, err:
+            self.w.error (_("can't open file `%s' for writing:\n%s")
+                          % (output, str (err)))
+            return
+        
+        entries = map (lambda x: x.key, self.index.selection ())
+        
+        if not entries:
+            entries = self.data.keys ()
+
+        url = Fields.URL (style)
+        
+        Pyblio.Style.Utils.generate (url, format, self.data, entries, file)
+        return
+
+    def format_entries (self, * arg):
+        if self.format_dg is None:
+            self.format_dg = Format.FormatDialog (self.w)
+            self.format_dg.Subscribe ('format-query', self.format_query)
+            
+        self.format_dg.show ()
+        return
+
     
     def update_status (self, status = -1):
         ''' redisplay status bar according to the current status '''
@@ -322,7 +383,13 @@ class Document (Connector.Publisher):
 
         Utils.set_cursor (self.w, 'clock')
         try:
-            self.data.update ()
+            try:
+                self.data.update ()
+            except (OSError, IOError), error:
+                Utils.set_cursor (self.w, 'normal')
+                self.w.error (_("Unable to save `%s':\n%s") % (str (self.data.key),
+                                                               str (error)))
+                return
         except:
             Utils.set_cursor (self.w, 'normal')
             self.w.error (_("An internal error occured during saving\nTry to Save As..."))
@@ -380,6 +447,15 @@ class Document (Connector.Publisher):
         self.issue ('exit-application', self)
         return
 
+    def drag_moved (self, entries):
+        if not entries: return
+        
+        for e in entries:
+            del self.data [e.key]
+
+        self.redisplay_index (1)
+        return
+    
     def drag_received (self, entries):
         for entry in entries:
             
@@ -462,7 +538,8 @@ class Document (Connector.Publisher):
         ''' updates the database and the display '''
 
         if old.key != new.key:
-            del self.data [old.key]
+            if self.data.has_key (old.key):
+                del self.data [old.key]
 
         if new.key:
             self.data [new.key] = new
@@ -513,7 +590,16 @@ class Document (Connector.Publisher):
 
     
     def sort_entries (self, * arg):
-        self.w.warning ("Not yet implemented")
+        if self.sort_dg is None:
+            self.sort_dg = SortDialog (self.selection.sort, self.w)
+            self.sort_dg.Subscribe ('sort-data', self.sort_view)
+        self.sort_dg.show ()
+        return
+
+
+    def sort_view (self, sort):
+        self.selection.sort = Sort.Sort (sort)
+        self.redisplay_index ()
         return
     
 
@@ -584,18 +670,19 @@ class Document (Connector.Publisher):
             self.w.error (_("Please install bug-buddy\nto use this feature"))
             return
         
-        command = 'bug-buddy --package=pybliographer --package-ver=%s &' % self.version
+        command = 'bug-buddy --package=pybliographer --package-ver=%s &' % version.version
         
         os.system (command)
         return
 
     
     def about (self, *arg):
-        about = GnomeAbout ('Pybliographic', self.version,
+        about = GnomeAbout ('Pybliographic', version.version,
                             _("This program is copyrighted under the GNU GPL"),
                             ['Frdric Gobry'],
                             _("Gnome interface to the Pybliographer system."),
                             'pybliographic-logo.png')
+        about.set_parent (self.w)
         
         link = GnomeHRef ('http://www.gnome.org/pybliographer',
                           _("Pybliographer Home Page"))
