@@ -17,10 +17,11 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: Editor.py,v 1.6 2000/03/14 16:27:06 fredgo Exp $
+# $Id: Editor.py,v 1.13 2000/04/04 08:32:56 fredgo Exp $
 
 import string, re
 from gnome.ui import *
+from gnome import config
 from gtk import *
 import GTK
 
@@ -33,6 +34,14 @@ from Pyblio.GnomeUI import FieldsInfo, Utils, Mime
 
 key_re = re.compile ("^[\w:_+-]+$")
 
+_newcontent = {
+    Fields.AuthorGroup : _("Last Name, First Name"),
+    Fields.Text        : _("Text"),
+    Fields.URL         : 'http://',
+    Fields.Date        : '2000',
+    Fields.Reference   : _("Reference"),
+    }
+
 
 class BaseField (Connector.Publisher):
     ''' common class to each specialized field editor '''
@@ -90,7 +99,6 @@ class BaseField (Connector.Publisher):
         else:
             (self.value, self.loss) = (None, 0)
             self.string = ''
-
         return
 
     
@@ -107,7 +115,40 @@ class BaseField (Connector.Publisher):
         return 1
         
 
-class Entry (BaseField):
+class TextBase (BaseField):
+    ''' Virtual class common to Text and Entry '''
+
+    def setup (self, entry):
+        BaseField.setup (self, entry)
+
+        if self.string and self.string [0] == '@':
+            self.string = ' ' + self.string
+        return
+
+    
+    def update (self, entry):
+        text = string.rstrip (self.edit.get_chars (0, -1))
+        if text == self.string: return 0
+
+        if text == '':
+            del entry [self.field]
+            return 1
+
+        self.update_content (entry, text)
+        return 1
+
+
+    def update_content (self, entry, text):
+        if text [0] == '@' and hasattr (entry, 'set_native'):
+            entry.set_native (self.field, string.lstrip (text [1:]))
+            return
+
+        text = string.lstrip (text)
+        entry [self.field] = Fields.Text (text)
+        return
+
+    
+class Entry (TextBase):
 
     def create_widget (self, h):
         if len (self.string) < 50:
@@ -134,16 +175,7 @@ class Entry (BaseField):
         return 1
 
 
-    def update_content (self, entry, text):
-        if text [0] == '@' and hasattr (entry, 'set_native'):
-            entry.set_native (self.field, text [1:])
-            return
-        
-        entry [self.field] = Fields.Text (text)
-        return
-
-
-class Text (BaseField):
+class Text (TextBase):
     
     def create_widget (self, h):
         w = GtkScrolledWindow ()
@@ -160,15 +192,6 @@ class Text (BaseField):
         return 1
 
 
-    def update_content (self, entry, text):
-        if text [0] == '@' and hasattr (entry, 'set_native'):
-            entry.set_native (self.field, text [1:])
-            return
-        
-        entry [self.field] = Fields.Text (text)
-        return
-
-
 class AuthorGroup (BaseField):
     
     def create_widget (self, h):
@@ -387,7 +410,9 @@ class RealEditor (Connector.Publisher):
         
         self.w = GtkVBox ()
         table  = GtkTable (2, 2)
-
+        table.set_border_width (5)
+        table.set_col_spacings (5)
+        
         table.attach (GtkLabel (_("Entry type")),
                       0, 1, 0, 1, yoptions = 0)
         table.attach (GtkLabel (_("Key")),
@@ -426,7 +451,7 @@ class RealEditor (Connector.Publisher):
 
         self.newfield_area = GtkHBox (spacing = 5)
         self.newfield_area.set_border_width (5)
-        self.newfield = GtkEntry ()
+        self.newfield = GnomeEntry ('newfield')
         self.newfield_area.pack_start (self.newfield)
 
         b = GtkButton (_("Create Field"))
@@ -520,10 +545,12 @@ class RealEditor (Connector.Publisher):
 
 
     def create_field (self, * arg):
-        text = string.strip (string.lower (self.newfield.get_text ()))
+        widget = self.newfield.gtk_entry ()
+        text = string.strip (string.lower (widget.get_text ()))
         if text == '': return
-        
-        self.entry [text] = Fields.Text (_("New text"))
+
+        newtype = Types.get_field (text).type
+        self.entry [text] = newtype (_newcontent [newtype])
         self.update_notebook ()
         return
     
@@ -537,16 +564,16 @@ class RealEditor (Connector.Publisher):
             modified = TRUE
         else:
             if not key_re.match (key):
-                Utils.error_dialog (_("Error"), _("Invalid key format"),
-                                    self.w.get_toplevel ())
+                GnomeErrorDialog (_("Invalid key format"),
+                                  self.w.get_toplevel ())
                 return None
 
-            key = Key.Key (self.entry.key.base, key)
+            key = Key.Key (database, key)
 
             if key != self.entry.key:
                 if database.has_key (key):
-                    Utils.error_dialog (_("Error"), _("Key already exists"),
-                                        self.w.get_toplevel ())
+                    GnomeErrorDialog (_("Key `%s' already exists") % str (key.key),
+                                      self.w.get_toplevel ())
                     return None
                 
                 self.entry.key = key
@@ -578,8 +605,11 @@ class NativeEditor (Connector.Publisher):
 
         self.entry    = entry
         self.database = database
-        self.original = database.get_native (entry.key)
-
+        if database.has_key (entry.key):
+            self.original = database.get_native (entry.key)
+        else:
+            self.original = ''
+        
         self.w = GtkText ()
         self.w.set_editable (TRUE)
         self.w.connect ('key_press_event', self.key_handler)
@@ -620,18 +650,29 @@ class Editor (Connector.Publisher):
         self.w = GtkDialog ()
         
         self.w.set_policy (TRUE, TRUE, FALSE)
-        self.w.set_title ('Edit')
+        self.w.set_title (_("Edit entry"))
         self.w.connect ('delete_event', self.close_dialog)
 
+        # set window size
+        ui_width  = config.get_int ('Pybliographic/Editor/Width=-1')
+        ui_height = config.get_int ('Pybliographic/Editor/Height=-1')
+
+        if ui_width != -1 and ui_height != -1:
+            self.w.set_default_size (ui_width, ui_height)
+
         if parent: self.w.set_transient_for (parent)
 
         self.apply_b = GnomeStockButton (STOCK_BUTTON_APPLY)
         self.apply_b.connect ('clicked', self.apply_changes)
         self.apply_b.show ()
-        
-        self.native_b = GtkButton (_("Native Editing"))
-        self.native_b.connect ('clicked', self.toggle_native)
-        self.native_b.show ()
+
+        # check if the database supports native editing
+        self.has_native = hasattr (database, 'get_native')
+
+        if self.has_native:
+            self.native_b = GtkButton (_("Native Editing"))
+            self.native_b.connect ('clicked', self.toggle_native)
+            self.native_b.show ()
         
         self.close_b = GnomeStockButton (STOCK_BUTTON_CANCEL)
         self.close_b.connect ('clicked', self.close_dialog)
@@ -646,7 +687,7 @@ class Editor (Connector.Publisher):
                                  0)
 
         self.w.action_area.add (self.apply_b)
-        self.w.action_area.add (self.native_b)
+        if self.has_native: self.w.action_area.add (self.native_b)
         self.w.action_area.add (self.close_b)
 
         self.entry       = entry
@@ -654,7 +695,9 @@ class Editor (Connector.Publisher):
         self.editor      = None
 
         # put the negated value, so that we can call toggle to switch and create
-        self.native_mode = not Config.get ('gnomeui/native-as-default').data
+        self.native_mode = not (self.has_native and
+                                Config.get ('gnome/native-as-default').data)
+
         self.toggle_native ()
         
         self.w.show ()
@@ -665,7 +708,8 @@ class Editor (Connector.Publisher):
         if self.native_mode:
             # real edition
             self.native_mode = FALSE
-            self.native_b.children () [0].set_text (_("Native Editing"))
+            if self.has_native:
+                self.native_b.children () [0].set_text (_("Native Editing"))
 
             if self.editor: self.editor.w.destroy ()
             self.editor = RealEditor (self.database,
@@ -678,7 +722,8 @@ class Editor (Connector.Publisher):
         else:
             # native edition
             self.native_mode = TRUE
-            self.native_b.children () [0].set_text (_("Standard Editing"))
+            if self.has_native:
+                self.native_b.children () [0].set_text (_("Standard Editing"))
             
             if self.editor: self.editor.w.destroy ()
             self.editor = NativeEditor (self.database,
@@ -703,6 +748,11 @@ class Editor (Connector.Publisher):
 
 
     def close_dialog (self, *arg):
+        alloc = self.w.get_allocation ()
+        config.set_int ('Pybliographic/Editor/Width',  alloc [2])
+        config.set_int ('Pybliographic/Editor/Height', alloc [3])
+        config.sync ()
+        
         self.w.destroy ()
         return
 
