@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 # 
-# $Id: pybliographer.py,v 1.3 2000/03/13 12:45:24 fredgo Exp $
+# $Id: pybliographer.py,v 1.5 2000/03/29 13:08:11 fredgo Exp $
 
 version  = "@version@"
 progname = "@package@"
@@ -74,7 +74,6 @@ sys.path.append (lib_pybdir)
 sys.path.insert (0, '.')
 sys.path.insert (0, './compiled')
 
-
 optlist, args = getopt.getopt (sys.argv [1:],
 			       'qf:nvh',
 			       ['quiet',
@@ -83,6 +82,9 @@ optlist, args = getopt.getopt (sys.argv [1:],
 				'help'])
 
 sys.argv = sys.argv [0:1] + args
+try:
+	sys.argv.remove ('--')
+except ValueError: pass
 
 quiet = 0
 
@@ -133,9 +135,6 @@ if not quiet:
 
 user_global = {'__builtins__' : __builtins__,
 	       '__name__'     : progname,
-	       'pyb_prefix'   : data_pybdir,
-	       'quiet'        : quiet,
-	       'version'      : version
 	       }
 
 user_local  = {}
@@ -149,11 +148,10 @@ for filename in sources:
 		pass
 	else:
 		execfile (filename, user_global)
-
+		
 # Fichiers passes en argument au programme
 if len (args) > 0 :
 	filename = args [0]
-	
 	try:
 		os.stat (filename)
 	except os.error:
